/* liblwevent/src/liblwevent/200_eventloop.h
 *
 *  (c)2007, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv2. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



/*! \defgroup eventloop Main event loop

This module controls overall program flow. The two main functions of interest are
lwevent_loop(), which implements a full event-driven programming loop (only returning when the
program should exit), and lwevent_wait(), which implements a single run of the event loop.

*/
/*!@{*/



/*! \brief Event loop exit flag.

This flag, if set, signifies that lwevent_loop() should exit after its next iteration. It can be
set by a signal handler or any other function in the program at any time. It is scanned after each
loop is completely processed.

*/
extern volatile int lwevent_loop_exit;



/*! \brief Event loop (loop forever).

\retval 0 on success (event loop exited due to lwevent_loop_exit flag).
\retval -1 on error (system call failed; see \a errno).

This function will call lwevent_wait() in a loop forever. The loop can be aborted by setting the
flag lwevent_loop_exit to non-zero. The loop will also be aborted if lwevent_wait() returns an
error (in which case \a errno can be used to determine the error).

*/
int lwevent_loop(void);



/*! \brief Event loop (loop once).

\param timeout_ms A timeout, in milliseconds. This function will return as soon as any events occur,
    but will return after \a timeout_ms milliseconds have elapsed.
\retval 0 on success (events occurred, timeout occurred).
\retval -1 on error (system call failed; see \a errno).

This function will run the event loop once, returning as soon as events are available (or the
timeout, in milliseconds, occurs). If any events do occur, they will be dispatched to the relevant
callback objects. The final action of this function is to free the memory associated with any
objects that are closed during the callbacks.

*/
int lwevent_wait(int timeout_ms);



/*!@}*/
/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4:syntax=c.doxygen
*/
